..  Copyright (C)  Brad Miller, David Ranum
    Permission is granted to copy, distribute and/or modify this document
    under the terms of the GNU Free Documentation License, Version 1.3 or 
    any later version published by the Free Software Foundation; with 
    Invariant Sections being Forward, Prefaces, and Contributor List, 
    no Front-Cover Texts, and no Back-Cover Texts.  A copy of the license
    is included in the section entitled "GNU Free Documentation License".


======================
Your Project Name Here
======================


General Introduction
::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   GeneralIntro/introduction.rst


Simple Python Data
::::::::::::::::::

.. toctree::
   :maxdepth: 2

   SimplePythonData/simpledata.rst

Python Turtle Graphics
::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   PythonTurtle/helloturtle.rst


Python Modules
::::::::::::::

.. toctree::
   :maxdepth: 2

   PythonModules/modules.rst

Functions
:::::::::

.. toctree::
   :maxdepth: 2

   Functions/functions.rst

Selection
:::::::::

.. toctree::
   :maxdepth: 2

   Selection/selection.rst


More About Iteration
::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   MoreAboutIteration/moreiteration.rst


Strings
:::::::

.. toctree::
   :maxdepth: 2

   Strings/strings.rst

Lists
:::::

.. toctree::
   :maxdepth: 2

   Lists/lists.rst


Files
:::::

.. toctree::
   :maxdepth: 2

   Files/files.rst


Dictionaries
::::::::::::

.. toctree::
   :maxdepth: 2

   Dictionaries/dictionaries.rst

Recursion
::::::::::

.. toctree::
   :maxdepth: 2

   Recursion/thinkpyrecursion.rst


Defining Classes
::::::::::::::::

.. toctree::
   :maxdepth: 2

   Classes/classesintro.rst
   Classes/fractions.rst


Abstraction and Data Structures
:::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   Introduction/introduction.rst

Analysis
::::::::

.. toctree::
   :maxdepth: 2

   AlgorithmAnalysis/analysis.rst

Basic Data Structures
:::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   BasicDS/basic.rst
   BasicDS/stacks.rst
   BasicDS/queues.rst
   BasicDS/deques.rst
   BasicDS/linkedlists.rst
   BasicDS/basic_ex.rst

Recursion
:::::::::

.. toctree::
   :maxdepth: 2

   Recursion/recursionsimple.rst
   Recursion/graphical.rst
   Recursion/recursioncomplex.rst
   Recursion/recursionexercises.rst


Sorting and Searching
:::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   SortSearch/searching.rst
   SortSearch/sorting.rst
   SortSearch/sortsearchexercises.rst

Trees and Tree Agorithms
::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   Trees/trees.rst
   Trees/implementation.rst
   Trees/bintreeapps.rst
   Trees/heap.rst
   Trees/bst.rst
   Trees/balanced.rst
   Trees/treeexercises.rst


Graphs and Graph Algorithms
:::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   Graphs/graphintro.rst
   Graphs/graphbfs.rst
   Graphs/graphdfs.rst
   Graphs/graphshortpath.rst
   Graphs/graphexercises.rst


Acknowledgements
::::::::::::::::
.. toctree::
    :maxdepth: 1

    FrontBackMatter/copyright.rst
    FrontBackMatter/prefaceinteractive.rst
    FrontBackMatter/foreword.rst
    FrontBackMatter/preface.rst
    FrontBackMatter/preface2e.rst
    FrontBackMatter/contrib.rst
    FrontBackMatter/fdl-1.3.rst

Indices and tables
::::::::::::::::::

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

